/* GCC */

#include <iostream>
#include <fstream>
#include <cstdio>
#include <cstdlib>
#include <algorithm>
#include <vector>
#include <cmath>
#include <stdint.h>
#include <utility>
#include <cstring>
#include <string>
#include <queue>
#include <cassert>

struct Node
{
    int v;
    int used;
    Node() : v(0), used(0) {}
    Node(int v, int u) : v(v), used(u) {}
    bool operator<(const Node& l) const
    {
        return v < l.v;
    }
    bool operator==(const Node& l) const
    {
        return v == l.v;
    }
};
using namespace std;

vector<vector<Node> > g;

#define NAME "solid"

#define X first
#define Y second
#define MP(x, y) make_pair((x), (y))

int limit;
int a[10] = {};
int n;
bool used[2000] = {};

bool check_line()
{
    if (min_element(a, a+limit) != a)
        return false;
    if (a[1] > a[limit-1])
        return false;
    return true;
}

bool bfs_check()
{
    bool marked[2000] = {};

    int start = 0;
    for (int i = 0; i < limit; ++i)
    {
        marked[a[i]] = true;
    }

    while (start < n && find(a, a+limit, start) != a+limit)
        ++start;

    queue<int> q;

    q.push(start);
    int COUNT = 0;

    while (!q.empty())
    {
        int v = q.front();
        q.pop();
        COUNT++;
        marked[v] = true;

        for (int i = 0; i < (int)g[v].size(); ++i)
        {
            int to = g[v][i].v;
            if (!marked[to])
            {
                marked[to] = true;
                q.push(to);
            }
        }
    }


    return COUNT == n-limit;
}

bool has_edge(int v, int u)
{
    return binary_search(g[v].begin(), g[v].end(), Node(u, 0));
}

bool check_edge()
{
    for (int i = 0; i < limit; ++i)
    {
        for (int j = 2; j <= limit-2; ++j)
        {
            int to = (i+j)%limit;
            if (has_edge(a[i], a[to]))
                return false;
        }
    }
    return true;
}

void remove_edge(int u, int v)
{
    vector<Node>::iterator it = lower_bound(g[u].begin(), g[u].end(), Node(v, 0));
    assert(it != g[u].end());
    if (it->used != 0)
        --it->used;
}

void backtrack(int j)
{
    if (j == limit)
    {
        if (!has_edge(a[0], a[limit-1]))
            return;
        if (!check_line())
            return;
        if (!bfs_check())
            return;
        if (!check_edge())
            return;

        for (int i = 0; i < limit-1; ++i)
        {
            remove_edge(a[i], a[i+1]);
            remove_edge(a[i+1], a[i]);
        }
        remove_edge(a[0], a[limit-1]);
        remove_edge(a[limit-1], a[0]);

        for (int i = 0; i < limit; ++i)
        {
            printf("%d%s", a[i]+1, ((i != limit-1)?" ":"\n"));
        }
        return;
    }
    if (j == 0)
    {
        for (int i = 0; i < n; ++i)
        {
            a[0] = i;
            used[i] = true;
            backtrack(1);
            used[i] = false;
        }
        return;
    }

    int vertex = a[j-1];
    for (int i = 0; i < (int)g[vertex].size(); ++i)
    {
        int to = g[vertex][i].v;
        if (!used[to] && g[vertex][i].used != 0)
        {
            used[to] = true;
            a[j] = to;
            backtrack(j+1);
            used[to] = false;
        }
    }
}

void long_line(int start)
{
    queue<int> q;

    bool used[2000] = {};
    vector<int> neigh;

    for (int i = 0; i < (int)g[start].size(); ++i)
    {
        if (g[start][i].used != 0)
            neigh.push_back(g[start][i].v);
    }
    sort(neigh.begin(), neigh.end());

    vector<int> gran;
    gran.push_back(start);
    q.push(neigh[0]);
    used[start] = true;

    while (!q.empty())
    {
        int v = q.front();
        q.pop();
        gran.push_back(v);

        used[v] = true;

        for (int i = 0; i < (int)g[v].size(); ++i)
        {
            int to = g[v][i].v;
            if (!used[to] && g[v][i].used != 0)
            {
                used[to] = true;
                q.push(to);
            }
        }
    }

    for (int i = 0; i < (int)gran.size(); ++i)
    {
        printf("%d%s", gran[i]+1, ((i != (int)gran.size()-1)?" ":"\n"));
    }

}

int main()
{
    freopen(NAME ".in", "r", stdin);
    freopen(NAME ".out", "w", stdout);

    scanf("%d", &n);
    getchar();

    g.resize(n);

    for (int i =0; i<n; ++i)
    {
        char line[2000*5];
        fgets(line, 10000, stdin);
        char *p = strtok(line, " \n");

        while (p != NULL)
        {
            int v = atoi(p)-1;
            p = strtok(NULL, " \n");
            g[i].push_back(Node(v, 2));
        }
        sort(g[i].begin(), g[i].end());
    }

    for (int i = 3; i <= min(n-1, 8); ++i)
    {
        limit = i;
        backtrack(0);
    }
/*
    for (int i = 0; i < n; ++i)
    {
        for (int j = 0; j < g[i].size(); ++j)
        {
            cerr << g[i][j].used << " ";
        }
        cerr << "\n";
    }
*/
    limit = 0;

    for (int i = 0; i < n; ++i)
    {
        for (int j = 0; j < (int)g[i].size(); ++j)
        {
            if(g[i][j].used != 0)
            {
                long_line(i);
                return 0;
            }
        }
    }

    return 0;
}
